let data = {
    editBattleTag: false,
    editPassword: false,
    editAva: false,
    editNickName: false,
    battleTag: null,
    password1: null,
    password2: null,
    userInfo: null,
    token: null,
    selectedRegion: 1,
    selectedAva: -1,
    editingNickName: null,
    regions: [{
        name: '国服',
        slug: 'CN'
    },
    {
        name: '亚服',
        slug: 'AISA'
    },
    {
        name: '美服',
        slug: 'US'
    },
    {
        name: '欧服',
        slug: 'EU'
    }
    ],
    avaArray: []
}

function onAvaClick() {
    data.editAva = true;
}

function onNickNameClick() {
    if (!data.userInfo) return;
    data.editNickName = true;
    data.editingNickName = data.userInfo.nickName;
}

function onBattletagClick() {
    data.editBattleTag = true;
}

function onPasswordClick() {
    data.editPassword = true;
}

function onLogoutClick() {
    oak.onLogoutClick();
}

function onDeleteAccountClick() {
    oak.onDeleteAccountClick();
}

function onRegionClick(index) {
    data.selectedRegion = index;
}

function onModalBackClick() {
    data.editBattleTag = false;
    data.editPassword = false;
    data.editAva = false;
    data.editNickName = false;
}

function onImageClick(index) {
    data.selectedAva = index
}

function onBattletagSave() {
    let battleTag = data.battleTag;
    let region = data.regions[data.selectedRegion].slug;
    if (/.{2}#[0-9]{4,}$/g.test(battleTag)) {
        postToNA("updateRemoteUserInfo", JSON.stringify({ battletag: battleTag, battlenetRegion: region }), function (res) {
            if (res != "0") {
                oak.showToast("修改失败，请稍后重试");
            } else {
                data.userInfo.battleTag = battleTag;
                data.userInfo.battlenetRegion = region;
                data.editBattleTag = false;
            }
        });
    } else {
        oak.showToast("战网Tag不合法");
    }
}

function onPasswordSave() {
    let password1 = data.password1;
    let password2 = data.password2;
    if (password1 == null || password1 != password2) {
        oak.showToast("两次密码不一致");
        return;
    }
    if (!/^[a-zA-Z]\w{5,11}$/g.test(password1)) {
        oak.showToast("密码必须以字母开头，长度在6~12之间，只能包含字母、数字和下划线");
        return;
    }

    postToNA("updateRemoteUserInfo", JSON.stringify({ passwordRaw: password1 }), function (res) {
        if (res != "0") {
            oak.showToast("修改失败，请稍后重试");
        } else {
            oak.showToast("修改成功");
            onModalBackClick();
        }
    });

}

function onAvaSaveClick() {
    let index = data.selectedAva;
    if (index < 0 || index >= data.avaArray.length) {
        oak.showToast("请选择头像");
        return;
    }
    let avaName = data.avaArray[index];
    postToNA("updateRemoteUserInfo", JSON.stringify({ avatarId: avaName }), function (res) {
        if (res != "0") {
            oak.showToast("修改失败，请稍后重试");
        } else {
            oak.showToast("修改成功");
            data.userInfo.avatarId = avaName;
            onModalBackClick();
        }
    });
}

function onBattletagChanged(e) {
    let battleTag = e.target.value;
    data.battleTag = battleTag;
}

function onNickNameChanged(e) {
    let nickName = e.target.value;
    data.editingNickName = nickName;
}

function checkNickNameValid(name) {
    if (name == null || typeof name != 'string' || name.length < 1 || name.length > 10) {
      return false;
    }
    return true;
}
function onNickNameSaveClick() {
    let name = data.editingNickName;
    if (!checkNickNameValid(name)) {
        oak.showToast("昵称必须是1-10个字符");
        return;
    }
    postToNA("updateRemoteUserInfo", JSON.stringify({ nickName: name }), function (res) {
        if (res != "0") {
            oak.showToast("修改失败，请稍后重试");
        } else {
            oak.showToast("修改成功");
            data.userInfo.nickName = name;
            onModalBackClick();
        }
    });
}

function onPasswordChanged1(e) {
    let password1 = e.target.value;
    data.password1 = password1;
}

function onPasswordChanged2(e) {
    let password2 = e.target.value;
    data.password2 = password2;
}

function onDoNothing() { }

let app;

function onLoad() {

    let fMax = 14;
    let mMax = 24;
    let newArray = [];
    for (let i = 1; i <= fMax; i++) {
        newArray.push('f_' + i);
    }
    for (let i = 1; i <= mMax; i++) {
        newArray.push('m_' + i);
    }
    data.avaArray = newArray;

    app = new Vue({
        el: '#app',
        data: {
            data: data
        },
        methods: {
            onAvaClick: onAvaClick,
            onNickNameClick: onNickNameClick,
            onBattletagClick: onBattletagClick,
            onPasswordClick: onPasswordClick,
            onLogoutClick: onLogoutClick,
            onModalBackClick: onModalBackClick,
            onRegionClick: onRegionClick,
            onImageClick: onImageClick,
            onDoNothing: onDoNothing,
            onBattletagSave: onBattletagSave,
            onPasswordSave: onPasswordSave,
            onBattletagChanged: onBattletagChanged,
            onPasswordChanged1: onPasswordChanged1,
            onPasswordChanged2: onPasswordChanged2,
            onAvaSaveClick: onAvaSaveClick,
            onNickNameChanged: onNickNameChanged,
            onNickNameSaveClick: onNickNameSaveClick,
            onDeleteAccountClick: onDeleteAccountClick
        }
    });
}